@@ -138,7 +138,8 @@ class MyQtApp(PFAS_SAT_ui.Ui_PFAS_SAT, QtWidgets.QMainWindow):
     # Help function
     @QtCore.Slot()
     def help_WM_Function(self):
-        QtGui.QDesktopServices.openUrl('https://pfas-sat.readthedocs.io/en/latest/WasteMaterialsProperties.html')
+        QtGui.QDesktopServices.openUrl('file:///'+str(Path(__file__).parent.parent/'html/WasteMaterialsProperties.html'))
+        #QtGui.QDesktopServices.openUrl('https://pfas-sat.readthedocs.io/en/latest/WasteMaterialsProperties.html')
 # =============================================================================
 #         self.help_window = QWebEngineView()
 #         sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
@@ -233,7 +234,6 @@ class MyQtApp(PFAS_SAT_ui.Ui_PFAS_SAT, QtWidgets.QMainWindow):
             self.PM_tab.setEnabled(True)
             
             self.PM_Help.clicked.connect(self.help_PM_Function)
-            self.WM_UncertaintyHelp.clicked.connect(self.help_MC_Function)
             
             # Disable flows that are not modeled.
             self.Med_Waste.setDisabled(True)
@@ -310,13 +310,15 @@ class MyQtApp(PFAS_SAT_ui.Ui_PFAS_SAT, QtWidgets.QMainWindow):
 #         self.help_window.setUrl(QtCore.QUrl('https://pfas-sat.readthedocs.io/en/latest/ProcessModels.html'))
 #         self.help_window.show()
 # =============================================================================
-        QtGui.QDesktopServices.openUrl('https://pfas-sat.readthedocs.io/en/latest/ProcessModels.html')
+        QtGui.QDesktopServices.openUrl('file:///'+str(Path(__file__).parent.parent/'html/ProcessModels.html'))
+        #QtGui.QDesktopServices.openUrl('https://pfas-sat.readthedocs.io/en/latest/ProcessModels.html')
 
 
     # Help function for uncertainty distributions
     @QtCore.Slot(str)
     def help_MC_Function(self):
-        QtGui.QDesktopServices.openUrl('https://pfas-sat.readthedocs.io/en/latest/Getting_started.html#uncertainty-distribution')
+        QtGui.QDesktopServices.openUrl('file:///'+str(Path(__file__).parent.parent/'html/Getting_started.html')+'#uncertainty-distribution')
+        #QtGui.QDesktopServices.openUrl('https://pfas-sat.readthedocs.io/en/latest/Getting_started.html#uncertainty-distribution')
 
 
     @QtCore.Slot()
@@ -1304,28 +1306,34 @@ class MyQtApp(PFAS_SAT_ui.Ui_PFAS_SAT, QtWidgets.QMainWindow):
         Dialog = QtWidgets.QDialog()
         Help_Gui_Widget = HelpGuide_ui.Ui_HelpGuide()
         Help_Gui_Widget.setupUi(Dialog)
-    
-        urlLink="<a href=\"https://pfas-sat.readthedocs.io/en/latest/Getting_started.html#create-new-project\">(Learn How)</a>" 
+        
+        urlLink = """<a href=\"{}\">(Learn How)</a>""".format('file:///'+str(Path(__file__).parent.parent/'html/Getting_started.html#create-new-project'))
+        #urlLink="<a href=\"https://pfas-sat.readthedocs.io/en/latest/Getting_started.html#create-new-project\">(Learn How)</a>" 
         Help_Gui_Widget.link_Create_project.setText(urlLink)
         Help_Gui_Widget.link_Create_project.setOpenExternalLinks(True)
-
-        urlLink="<a href=\"https://pfas-sat.readthedocs.io/en/latest/Getting_started.html#flow-analysis\">(Learn How)</a>" 
+        
+        urlLink = """<a href=\"{}\">(Learn How)</a>""".format('file:///'+str(Path(__file__).parent.parent/'html/Getting_started.html#flow-analysis'))
+        #urlLink="<a href=\"https://pfas-sat.readthedocs.io/en/latest/Getting_started.html#flow-analysis\">(Learn How)</a>" 
         Help_Gui_Widget.link_FA.setText(urlLink)
         Help_Gui_Widget.link_FA.setOpenExternalLinks(True)
 
-        urlLink="<a href=\"https://pfas-sat.readthedocs.io/en/latest/Getting_started.html#monte-carlo-simulation\">(Learn How)</a>" 
+        urlLink = """<a href=\"{}\">(Learn How)</a>""".format('file:///'+str(Path(__file__).parent.parent/'html/Getting_started.html#monte-carlo-simulation'))
+        #urlLink="<a href=\"https://pfas-sat.readthedocs.io/en/latest/Getting_started.html#monte-carlo-simulation\">(Learn How)</a>" 
         Help_Gui_Widget.link_MC.setText(urlLink)
         Help_Gui_Widget.link_MC.setOpenExternalLinks(True)
 
-        urlLink="<a href=\"https://pfas-sat.readthedocs.io/en/latest/Getting_started.html#sensitivity-analysis\">(Learn How)</a>" 
+        urlLink = """<a href=\"{}\">(Learn How)</a>""".format('file:///'+str(Path(__file__).parent.parent/'html/Getting_started.html#sensitivity-analysis'))
+        #urlLink="<a href=\"https://pfas-sat.readthedocs.io/en/latest/Getting_started.html#sensitivity-analysis\">(Learn How)</a>" 
         Help_Gui_Widget.link_SA.setText(urlLink)
         Help_Gui_Widget.link_SA.setOpenExternalLinks(True)
 
-        urlLink="<a href=\"https://pfas-sat.readthedocs.io/en/latest/doc_PFAS_SAT.html\">(Learn How)</a>" 
+        urlLink = """<a href=\"{}\">(Learn How)</a>""".format('file:///'+str(Path(__file__).parent.parent/'html/doc_PFAS_SAT.html'))
+        #urlLink="<a href=\"https://pfas-sat.readthedocs.io/en/latest/doc_PFAS_SAT.html\">(Learn How)</a>" 
         Help_Gui_Widget.link_CodeDoc.setText(urlLink)
         Help_Gui_Widget.link_CodeDoc.setOpenExternalLinks(True)
 
-        urlLink="<a href=\"https://pfas-sat.readthedocs.io/en/latest/contributing.html\">(Learn How)</a>" 
+        urlLink = """<a href=\"{}\">(Learn How)</a>""".format('file:///'+str(Path(__file__).parent.parent/'html/contributing.html'))
+        #urlLink="<a href=\"https://pfas-sat.readthedocs.io/en/latest/contributing.html\">(Learn How)</a>" 
         Help_Gui_Widget.link_Contr.setText(urlLink)
         Help_Gui_Widget.link_Contr.setOpenExternalLinks(True)        
         
