@@ -17,11 +17,12 @@ class Worker_MC(QtCore.QThread):
     UpdatePBr_Opt = QtCore.Signal(dict)
     Report = QtCore.Signal(dict)
 
-    def __init__(self, parent, project, InputFlow_object, n, seed):
+    def __init__(self, parent, project, InputFlow_object, n, seed=None, TypeOfPFAS='All'):
         super().__init__(parent)
         self.project = project
         self.n = n
         self.seed = seed
+        self.TypeOfPFAS = TypeOfPFAS
         self.InputFlow_object = InputFlow_object
         warnings.filterwarnings("ignore", category=RuntimeWarning)
 
@@ -29,7 +30,7 @@ class Worker_MC(QtCore.QThread):
         self.UpdatePBr_Opt.emit(0)
         Time_start = time()
         self.project.setup_MC(self.InputFlow_object, seed=self.seed)
-        MC_results_raw = self.project.MC_Run(n=self.n, signal=self.UpdatePBr_Opt)
+        MC_results_raw = self.project.MC_Run(n=self.n, TypeOfPFAS=self.TypeOfPFAS, signal=self.UpdatePBr_Opt)
         MC_results = self.project.Result_to_DF(MC_results_raw)
         Time_finish = time()
         self.UpdatePBr_Opt.emit(100)
