@@ -13,11 +13,43 @@ from .ProcessModel import ProcessModel
 
 class Landfill(ProcessModel):
     """
-    Assumptions:
-        1. No volatilization or degradation of PFAS.
-        2. Steady state.
-        3. PFAS-containing waste and bulk MSW are well mixed.
-        4. Annual time horizon.
+************
+Landfill
+************
+
+While the model describes a generic landfill, there are in practice four types of landfills (MSW, hazardous waste, C&D waste, ash). Each of these
+types of landfill includes the same basic processes as illustrated in Figure below and each type may be represented by adjusting default parameters.
+They may be unlined (e.g., many C&D landfills), have a single liner system (e.g., most MSW landfills), or be double-lined (e.g., hazardous waste
+landfills). The landfills may or may not have active gas collection and control systems. If there is an active gas control system utilizing a flare
+or engine, then some fraction of the volatilized or aerosolized PFAS may be destroyed. The PFAS that is not released remains stored in the landfill.
+
+
+To calculate PFAS release, the disposed PFAS-containing waste material is assumed to be well mixed with the bulk MSW. The area occupied by the
+disposed waste is estimated based on a default parameter that represents the mass of total waste that can be disposed per unit area. The area
+occupied by the PFAS-containing waste mixed in with MSW is coupled with the leachate generation rate (volume/area-time) to estimate the
+volume of leachate produced. The partitioning of PFAS from the solid waste to the aqueous phase is modeled using a liquid-solid partition
+coefficient normalized to the amount of organic carbon. Model predictions are based on achievement of equilibrium. By default, it
+is assumed that no volatilization occurs, but a user can enter a fraction of PFAS that is volatilized.
+
+
+The partition coefficient is used to estimate the concentration of PFAS in the liquid and solids. The concentration in the liquid changes throughout
+the year as is leached to the leachate collection system (i.e., it is assumed that leaching is uniform throughout the year and continuously removes
+PFAS from the mixture). The leachate collection efficiency is used to calculate the fraction of leachate that is collected and subsequently treated.
+The landfill process models in the SAT is designed so that by changing default parameters, a variety of landfill processes can be represented. For
+example, a C&D landfill without a liner would be modeled with no collection efficiency, all the generated leachate would be released to groundwater.
+A double-lined hazardous waste landfill could be modeled by increasing the leachate collection efficiency.
+
+=============================
+Assumptions and Limitations:
+=============================
+
+#. The organic carbon-normalized partition coefficient assumes that the organic carbon in different materials generally
+   have the PFAS sorption capacity. However, material-specific coefficients were developed for activated carbon,
+#. Volatilization is assumed to be zero by default due to a lack of data. However, the user may assign a fraction of
+   the PFAS to be volatilized.
+#. Future work is also required to implement a dynamic (i.e., non-equilibrium) model to account for changes in the
+   organic C content of over time as landfilled materials decompose, and the effectiveness of cover system improves.
+#. PFAS release is based on 1 year. A longer time horizon would result in additional PFAS release.
     """
     ProductsType = ['LFLeachate']
 
