@@ -38,5 +38,5 @@ class SurfaceWaterRelease(ProcessModel):
         if not normalized:
             report['Release'] = self.Inc_flow.PFAS
         else:
-            report['Release'] = self.Inc_flow.PFAS / self.Inc_flow.PFAS
+            report['Release'] = round(self.Inc_flow.PFAS / self.Inc_flow.PFAS * 100, 2)
         return(report)
